@@ -1,8 +1,7 @@
 from urllib.request import urlopen as uReq
 from bs4 import BeautifulSoup
 import csv 
-import os 
-
+import os
 
 
 import pygame
@@ -10,10 +9,7 @@ import pygame
 
 def main():
 
-
-    pygame.image.load('snake6.png')
-
-
+    pygame.image.load("./snake6.png")
 
     # January = February = March = April = May = June = July = August = September = October = November = December = []
     # year = [January, February, March, April, May, June, July, August, September, October, November, December]
